<?php

/**
 * Class blogData
 */
class BlogData
{
    public $pages = array();

    const FIRST_PAGE = "First";
    const NEXT_PAGE = "Next";
    const PREV_PAGE = "Prev";
    const LAST_PAGE = "Last";

    /** @var BlogDataPage $currentPage */
    private $currentPage;

    /** @var BlogEnv */
    private $blogEnv;

    public function __construct(BlogEnv $env, $currentKey)
    {
        $this->blogEnv = $env;
        $this->getBlogData($this->blogEnv->getBlogPathPublished());
        $this->setCurrentPage($currentKey);
    }

    /**
     * @return BlogDataPage
     */
    public function getCurrentPage()
    {
        return $this->currentPage;
    }

    /**
     * @param $direction
     * @return BlogDataPage
     */
    public function getPage($direction)
    {
        $page = new BlogDataPage($this->blogEnv);
        try {
            $keys = array_keys($this->pages);
            $numPages = count($keys);
            $pageIdx = -1;
            $currIdx = $this->currentPage->getPosition();
            $this->blogEnv->Log_Debug("getPage:: getting Page Option");
            switch ($direction){
                case self::FIRST_PAGE:
                    $pageIdx = 0;
                    break;
                case self::NEXT_PAGE:
                    $pageIdx = $currIdx - 1;
                    break;
                case self::PREV_PAGE:
                    $pageIdx = $currIdx + 1;
                    break;
                case self::LAST_PAGE:
                    if ($numPages > 0)
                        $pageIdx = $numPages - 1;
                    break;
                default:
                    return $page;

            }
            if (!$this->havePages()){
                return $page;
            }
            if ($pageIdx < 0 || $pageIdx >= $numPages) {
                return $page;
            }
            $page = $this->pages[$keys[$pageIdx]];

        } catch (Exception $ex) {
            $this->blogEnv->Log_Error("getPage:: Exception " . $ex->getMessage());
        }
        return $page;
    }

    /**
     * @param  string $dir
     * @return array
     *
     */
    public function getBlogFiles($dir)
    {
        $files = array();
        try {
            $result = False;
            if ($this->blogEnv->getOrderBy() == BlogEnv::OrderByName){
                $result = $this->scanDirByName($dir);
            }else{
                $result = $this->scanDirByDate($dir);
            }
            if (!$result){
                $this->blogEnv->Log_Debug("scandir result is false");
                return $files;
            }
            //Remove . and .. directories
            //$result = array_diff($result, array('.', '..'));
            $files = array_filter($result, function ($v) {
                if (substr($v, 0, 1) == '.') {
                    $this->blogEnv->Log_Debug("Skipping dot file: " . $v);
                    return false;
                }
                $this->blogEnv->Log_Debug("Adding file: ".$v);
                return true;
            });
        }catch (Exception $ex){
            $files = array();
        }
        return $files;
    }

    function scanDirByName($dir) {
        $files = array();
        try {
            $result = scandir($dir, SCANDIR_SORT_DESCENDING);
            if (!$result){
                $this->blogEnv->Log_Debug("scandir result is false");
                return $files;
            }
        }catch (Exception $ex){
            $this->blogEnv->Log_Error("Exception " . $ex->getMessage() . " processing dir: " . $dir);
        }
        return ($files) ? $files : false;
    }
    function scanDirByDate($dir) {
        $files = array();
        try {
            foreach (scandir($dir) as $file) {
                $files[$file] = filemtime($dir . '/' . $file);
            }
            arsort($files);
            $files = array_keys($files);
        }catch (Exception $ex){
            $this->blogEnv->Log_Error("Exception " . $ex->getMessage() . " processing dir: " . $dir);
        }
        return ($files) ? $files : false;
    }

    public function getBlogData($dir)
    {
        try {
            $files = $this->getBlogFiles($dir);
            foreach ($files as $item) {
                $page = new BlogDataPage($this->blogEnv);
                $page->setBlogItem($dir, $item);
                if ($page->isDirectory()) {
                    $this->getBlogData($dir . $item . DIRECTORY_SEPARATOR);
                }else{
                    if (!$this->blogEnv->isAllowedDocumentType($page->getFileExtension())) {
                        $this->blogEnv->Log_Debug("Skipping unsanctioned file: " . $page->getFullFilename());
                        continue;
                    }
                    $idx = count($this->pages);
                    $key = $page->getKey();
                    $page->position = $idx;
                    $this->pages[$key] = $page;
                    $this->blogEnv->Log_Debug("Adding blog Page(".$idx."): ".$page->getFullFilename());
                }
            }
        } catch (Exception $ex) {
            $this->blogEnv->Log_Error("Exception " . $ex->getMessage() . " processing dir: " . $dir);
        }
    }

    public function setCurrentPage($key)
    {
        $this->currentPage = new BlogDataPage($this->blogEnv);
        $page = $this->getPageByKey($key);
        if ($page->isValid()){
            $this->currentPage = $page;
            return;
        }
        $this->currentPage = $this->getPage(BlogData::FIRST_PAGE);
    }

    public function havePages()
    {
        return count($this->pages) > 0;
    }

    /**
     * @param string $key
     * @return BlogDataPage
     *
     */
    public function getPageByKey($key)
    {
        try {
            $this->blogEnv->Log_Debug("getting page for key: " . $key);
            foreach ($this->pages as $item) {
                /** @var  BlogDataPage $item */
                $itemkey = str_replace("\"", "", $key);
                $this->blogEnv->Log_Debug("Key: " . $item->getKey() . " = " . $itemkey);
                if (strcmp($item->getKey(), $itemkey) == 0) {
                    return $item;
                }
            }
            $this->blogEnv->Log_Debug("Key Not Found");
        } catch (Exception $ex) {
            $this->blogEnv->Log_Error("Exception " . $ex->getMessage());
        }
        return new BlogDataPage($this->blogEnv);
    }

    private function URL_exists($url)
    {
        $headers = get_headers($url);
        return stripos($headers[0], "200 OK") ? true : false;
    }

    public function getPageTitle(BlogDataPage $page)
    {
        return $page->getTitle();
    }

    /**
     * @param BlogDataPage $page
     * @param bool $shortDate
     * @return string
     */
    public function getPageDateDisplay($page, $shortDate = false)
    {
        $pageUtc = $page->getPublishTimestamp();
        if ($shortDate){
            $result = strftime("%m/%d/%Y", $pageUtc);
        }else{
            $result = strftime("%m/%d/%Y %X %Z", $pageUtc);
        }
        return $result;
    }

    /**
     * @return string
     */
    public function blogCreateToc()
    {
        $tocDisplay = '<ul class="' .BlogEnv::BlogHTMLId_TocList. '">' . PHP_EOL;
        $tocDisplay .= $this->buildDisplayTOC('');
        $tocDisplay .= '</ul>' . PHP_EOL;
        $this->blogEnv->Log_Debug("Got Blog TOC HTML");
        return $tocDisplay;
    }

    /**
     * @param string $dir
     * @return string
     */
    private function buildDisplayTOC($dir)
    {
        $toc = "";
        try {
            if (!isset($dir) || $dir == ''){
                $dir = $this->blogEnv->getBlogPathPublished();
            }

            $files = $this->getBlogFiles($dir);
            foreach ($files as $item) {
                $page = new BlogDataPage($this->blogEnv);
                $page->setBlogItem($dir, $item);
                if (substr($page->getFilename(), 0, 1 ) == "."){
                    continue;
                }
                $title = $page->getTitle();
                if ($page->isDirectory()) {
                    $href = '<a class="'.BlogEnv::BlogHTMLId_TocListFolder.'" href=#>'.$title.'</a>';
                    $toc .= '<li>' . $href . PHP_EOL;
                    $toc .= '<ul>' . PHP_EOL;
                    $toc .= $this->buildDisplayTOC($dir . $item . DIRECTORY_SEPARATOR);
                    $toc .= '</ul>' . PHP_EOL;
                    $toc .= '</li>' . PHP_EOL;
                } else {
                    if ($this->blogEnv->isAllowedDocumentType($page->getFileExtension())) {
                        $pageDate = $this->getPageDateDisplay($page, true);
                        $listing = '<div class="'.BlogEnv::BlogHTMLId_TocDoc.'">';
                        $listing .= '<div class="'.BlogEnv::BlogHTMLId_TocDocDate.'">';
                        $listing .= $pageDate;
                        $listing .= '</div>';
                        $listing .= '<div class="'.BlogEnv::BlogHTMLId_TocDocTitle.'">';
                        $listing .= $title;
                        $listing .= '</div>';
                        $listing .= '</div>';
                        $url = $page->getBlogViewerUrl();
                        $href = '<a class="'.BlogEnv::BlogHTMLId_TocListItem;
                        $href .= '" href="' . $url . '">' . $listing . '</a>';
                        $toc .= '<li>' . $href . '</li>' . PHP_EOL;
                    }
                }
            }
        } catch (Exception $ex) {
            $this->blogEnv->Log_Error("Exception building display toc");
        }
        return $toc;
    }

    /**
     * @param BlogDataPage $page
     * @return string
     */
    private function getPageUrl($page)
    {
        $rootdir = $this->blogEnv->getBlogWebRootPath();
        $pageDir = $page->getParentDir();
        $subdir = str_replace($rootdir, "", $pageDir);
        $tmp = $this->blogEnv->getBlogUrlWebRoot()
            . $subdir
            . $page->getFilename();
        $tmp2 = str_replace("/\\", "/", $tmp);
        $url = str_replace("\\", "/", $tmp2);
        return $url;
    }

    public function getBlogViewerDocumentSectionHtml(BlogDataPage $page){
        $ext = $page->getFileExtension();
        switch ($ext){
            case "TXT":
                $txtblocks = file($page->getFullFilename(),FILE_IGNORE_NEW_LINES);
                //Txt we will read the file and parse it to simplified html
                $html = "<div id=".BlogEnv::BlogHTMLId_blogDocTxt.">".PHP_EOL;
                foreach ($txtblocks as $paragraph){
                    $html = $html . "<p>";
                    $html = $html . $paragraph;
                    $html = $html . "</p>".PHP_EOL;
                }
                $html = $html . "</div>".PHP_EOL;
                return $html;
            case "PDF":
                $url = $this->getPageUrl($page);
                switch ($this->blogEnv->getPDFViewerOption()){
                    case BlogEnv::ViewPDFInPDFJSViewer:
                        $pdfjsUrl = $this->blogEnv->getPdfViewerPDFJSURL();
                        $url = $pdfjsUrl . $url;
                        break;
                }
                break;
            default:
                $url = $this->getPageUrl($page);
        }

        //Default to showing in iframe.
        $url = str_replace(" ", "%20", $url);
        $html = "<iframe id=".BlogEnv::BlogHTMLId_blogDocIFrame;
        $html = $html . " sandbox";
        $html = $html . " src='".$url."'";
        $html = $html . ">";
        $html = $html . "</iframe>";
        return $html;
    }


}