<?php

class BlogDataPage
{
    private $filename;
    private $title;
    private $publishTimestamp;
    private $parentDir;
    public $position;

    /** @var BlogEnv */
    private $blogEnv;

    /**
     * BlogDataPage constructor.
     * @param BlogEnv $blogEnv
     */
    public function __construct($blogEnv)
    {
        $this->blogEnv = $blogEnv;
        $this->parentDir = dirname($blogEnv->getNoBlogPagePath()).DIRECTORY_SEPARATOR;
        $this->filename = basename($blogEnv->getNoBlogPagePath());
        $this->publishTimestamp = filemtime($this->getFullFilename());
        $this->title = $this->getPageTitle();
        $this->position = -1;
    }

    /**
     * @return bool
     */
    public function isDirectory()
    {
        if (!file_exists($this->getFullFilename())) {
            return false;
        }
        return is_dir($this->getFullFilename());
    }

    /**
     * @return string
     */
    public function getKey()
    {
        return strtoupper($this->filename);
    }

    /**
     * @return string
     */
    public function getFilename()
    {
        return $this->filename;
    }

    /**
     * @return string
     */
    public function getFilenameNoExtension()
    {
        $path_parts = pathinfo($this->getFullFilename());
        return $path_parts['filename'];
    }

    public function getFileExtension()
    {
        return strtoupper(pathinfo($this->filename, PATHINFO_EXTENSION));
    }

    public function getPublishTimestamp()
    {
        return $this->publishTimestamp;
    }

    /**
     * @param string $parentDirectory
     * @param string $filename
     * @param int $idx
     */
    public function setBlogItem($parentDirectory, $filename)
    {
        $this->filename = $filename;
        $this->parentDir = $parentDirectory;
        if ($this->isDirectory()) {
            $this->title = $this->filename;
        } else {
            $this->title = $this->getPageTitle();
        }
        $this->publishTimestamp = filemtime($this->getFullFilename());
    }


    public function getParentDir()
    {
        return $this->parentDir;
    }

    public function getFullFilename()
    {
        return $this->parentDir . $this->filename;
    }

    /**
     * @return string
     */
    public function getTitle()
    {
        return $this->title;
    }

    public function isPDF()
    {
        if (strcasecmp($this->getFileExtension(), "PDF") == 0) {
            return true;
        }
        return false;
    }

    public function isValid()
    {
        if (empty($this->filename)) {
            return false;
        }
        if ($this->getPosition() < 0) {
            return false;
        }

        return true;
    }

    private function getPageTitle()
    {
        $title = "Unknown Title";
        try {
            $fp = file_get_contents($this->getFullFilename());

            $res = preg_match("/<title>(.*)<\/title>/siU", $fp, $title_matches);
            if (!$res)
                return $this->getFilenameNoExtension();

            // Clean up title: remove EOL's and excessive whitespace.
            $title = preg_replace('/\s+/', ' ', $title_matches[1]);
            $title = trim($title);
        } catch (Exception $ex) {
            $this->blogEnv->Log_Error("Exception getting PageTitle for " . $this->getFullFilename());
        }
        return $title;
    }

    public function getPosition()
    {
        return $this->position;
    }

    public function getBlogViewerUrl()
    {
        $key = $this->getKey();
        $url = $this->blogEnv->getBlogUrlViewerPage()
            . "?"
            . $this->blogEnv::BlogArgItem
            . "=$key";
        return $url;
    }
}
