<?php

/**
 * Class blogEnv
 */
class BlogEnv extends TBSWEnvUtils
{
    const OrderByDate = "date";
    const OrderByName = "Name";

    private $installPath;
    private $documentsPublishedFilePath;
    private $documentsUnPublishedFilePath;
    private $allowedDocumentExtensions;

    private $viewerPageFilePath;
    private $noBlogsPagePath;
    private $pdfDocumentViewerOption;
    private $orderBy;

    private $logLevel;

    const PdfJsViewer = __DIR__ . DIRECTORY_SEPARATOR . "Distributions" . DIRECTORY_SEPARATOR . "pdfjs" . DIRECTORY_SEPARATOR . "web" . DIRECTORY_SEPARATOR . "viewer.html";
    const BlogManagerInterface = "elFinderInterface.php";
    const BlogManagerConnector = "elFinderConnector.php";

    const BlogEnvironment = "TBSWBlogEnv";
    const BlogArgItem = "bgitem";
    const BlogArgEnv = "bvenv";

    const BlogHTMLId_Article = "blogArticle";


    const BlogHTMLId_TocButton = "blogTocButton";
    const BlogHTMLId_Navigation = "blogNavigation";
    const BlogHTMLId_NavButton = "blogNavButton";

    const BlogHTMLId_TocSection = "blogTocSection";
    const BlogHTMLId_TocList = "blogTocList";
    const BlogHTMLId_TocListItem = "blogTocListItem";
    const BlogHTMLId_TocListFolder = "blogTocListFolder";
    const BlogHTMLId_TocDoc = "blogTocDoc";
    const BlogHTMLId_TocDocDate = "blogTocDocDate";
    const BlogHTMLId_TocDocTitle = "blogTocDocTitle";
    const BlogHTMLId_DocumentSection = "blogSection";
    const BlogHTMLId_Header = "blogHeader";
    const BlogHTMLId_HeaderTitle = "blogHeaderTitle";
    const BlogHTMLId_HeaderDate = "blogHeaderDate";
    const BlogHTMLId_blogViewerArea = "blogViewerArea";
    const BlogHTMLId_blogDocIFrame = "blogDocIframe";
    const BlogHTMLId_blogDocTxt = "blogDocTxt";


    const ViewPDFInPDFJSViewer = "PDFJS";
    const ViewPDFInNativeBrowser = "Browser";

    public function __construct($logLevel, $data = null)
    {
        parent::__construct($logLevel);
        if ($data != null) {
            $this->LoadFromB64Json($data);
            return;
        }

        //Get the TBSW Blog Installation Path.
        $this->installPath = __DIR__ . DIRECTORY_SEPARATOR;
        $this->noBlogsPagePath = $this->installPath . "NoBlogPages.html";

        $this->allowedDocumentExtensions = [];
        $this->orderBy = BlogEnv::OrderByDate;
    }

    /**
     * @param string $fileExtension
     */
    public function addDocumentType($fileExtension)
    {
        $key = strtoupper((trim($fileExtension)));
        if ($this->allowedDocumentExtensions == null || !in_array($key, $this->allowedDocumentExtensions)) {
            $this->allowedDocumentExtensions[] = $key;
        }
    }

    /**
     * @param array $fileExtensions
     */
    public function addDocumentTypes($fileExtensions)
    {
        foreach ($fileExtensions as $ext) {
            $this->addDocumentType($ext);
        }
    }

    /**
     * @param string $fileExtension
     * @return bool
     */
    public function isAllowedDocumentType($fileExtension)
    {
        $ext = strtoupper(trim($fileExtension));
        if (in_array($ext, $this->allowedDocumentExtensions)) return true;
        return false;
    }

    /**
     * @param string $path
     */
    public function setPathDocumentsPublished($path)
    {
        $this->documentsPublishedFilePath = $path;
    }

    /**
     * @param string $path
     */
    public function setPathDocumentsUnPublished($path)
    {
        $this->documentsUnPublishedFilePath = $path;
    }

    /**
     * @param $path
     */
    public function setBlogViewerPage($path)
    {
        $this->viewerPageFilePath = $path;
    }

    /**
     * @return string
     */
    public function getPathDistributions()
    {
        return $this->installPath;
    }

    /**
     * @return mixed
     */
    public function getBlogUrlDistributions()
    {
        return $this->getUrlFromFullPath($this->installPath);
    }

    /**
     * @return mixed
     */
    public function getBlogUrlViewerPage()
    {
        return $this->getUrlFromFullPath($this->viewerPageFilePath);
    }

    /**
     * @return string
     */
    public function getBlogPathPublished()
    {
        if ($this->documentsPublishedFilePath == null){
            $this->documentsPublishedFilePath = $this->getBlogWebRootPath()."Published-Documents-NOT-SET";
        }
        return $this->documentsPublishedFilePath;
    }

    /**
     * @return mixed
     */
    public function getBlogPathUnPublished()
    {

        return $this->documentsUnPublishedFilePath;
    }

    /**
     * @param string $option
     */
    public function setPDFViewerOption($option)
    {
        $this->pdfDocumentViewerOption = $option;
    }

    /**
     * @return string
     */
    public function getPDFViewerOption()
    {
        return $this->pdfDocumentViewerOption;
    }
    /**
     * @return string
     */
    public function getPdfViewerPDFJSURL()
    {
        $file =  BlogEnv::PdfJsViewer;
        $url = $this->getUrlFromFullPath($file);
        $url = $url . "?file=";
        return $url;
    }

    /**
     * @return string
     */
    public function getBlogUrlWebRoot()
    {
        return $this->getWebRootUrl();
    }

    /**
     * @return string
     */
    public function getBlogUrlMangerInterface()
    {
        $url = $this->getBlogUrlDistributions() . BlogEnv::BlogManagerInterface;
        $json = json_encode(get_object_vars($this));
        $url = $url . "?" . BlogEnv::BlogArgEnv . '=' . base64_encode($json) . '';
        return $url;
    }

    /**
     * @return string
     */
    public function getBlogUrlManagerConnector()
    {
        $url = $this->getBlogUrlDistributions() . BlogEnv::BlogManagerConnector;
        $json = json_encode(get_object_vars($this));
        $url = $url . "?" . BlogEnv::BlogArgEnv . '=' . base64_encode($json) . '';
        return $url;
    }

    /**
     * @return string
     */
    public function getHTMLPageHeadViewer()
    {
        $results = '<link rel="stylesheet" href="' . $this->getBlogUrlDistributions() . 'blog.css">' . PHP_EOL;
        $results .= '<script src="' . $this->getBlogUrlDistributions() . 'blog.js"></script>' . PHP_EOL;
        return $results;
    }

    /**
     * @return string
     */
    public function getCurrentBlogItemArgument()
    {
        $currentKey = "";
        if (isset($_GET[BlogEnv::BlogArgItem])) {
            $currentKey = strtoupper($_GET[BlogEnv::BlogArgItem]);
        }
        return $currentKey;
    }

    /**
     * @return string
     */
    public function getBlogWebRootPath()
    {
        return $this->getWebRootPath();
    }

    /**
     * @return string
     */
    public function getBlogUrlPublished()
    {
        return $this->getUrlFromFullPath($this->documentsPublishedFilePath);
    }

    /**
     * @return string
     */
    public function getBlogUrlUnPublished()
    {
        return $this->getUrlFromFullPath($this->documentsUnPublishedFilePath);
    }

    public function setNoBlogPagePath(string $noBlogPagePath)
    {
        $this->noBlogsPagePath = $noBlogPagePath;
    }

    public function getNoBlogPagePath()
    {
        return $this->noBlogsPagePath;
    }

    public function setOrderBy($option){
        $this->orderBy = $option;
    }
    public function getOrderBy(){
        return $this->orderBy;
    }
}


