#Overview
TBSW Blog SDK allow a website to easily add a 
file based blog including an "Management" console that allows 
for blog file content creation and maintenance.

#Website Integration

##Install the SDK
To integrate the TBSW Blog into a website 
simply copy the Blog SDK files into a sub directory 
of the site. 
We recommend that TBSW Blog SDK be 
placed in its own directory so that it will not 
conflict with other packages your site may use.

**_For Example:_**
If the root of your web site is mywebsite,
1. Create a directory under mywebsite for the sdk. 
IE mywebsite\distributions\blogsdk
2. Copy the TBSW Blog Sdk file into the directory 
created in step 1.

The Blog SDK also requires our TBSW-PHPUtils package. SImply copy 
the files of this package into a seperate directory on youe web site
Installing 
**_For Example:_**
If the root of your web site is mywebsite,
1. Create a directory under mywebsite for the sdk. 
IE mywebsite\distributions\tbswutils
2. Copy the TBSW PHPUtils package files into the directory 
created in step 1.

##Viewing Blog Documents
You will need to create a PHP page that will allow your web users to view the blog
documents for your site. This page is 
where your site user will view the blog documents and 
the Blog Table of Contents(TOC). 
<br>An Example of this page is included in the TBSW Blog SDK.
<br>See Examples/siteBlogViewer.php 
<br>This view may be used as is or customized as you see fit.

The next few sections describe how to build a viewer page.

###Load the TBSW Blog SDK
In your viewer page load the TBSW Blog 
package and other TBSW prerequisites by including these line in your viewer page:
```PHP
require_once "<TBSW PHPUtils Installed Directory>UtilAutoload.php";
require_once "<TBSW Blog Installed Directory>BlogAutoload.php";
```
###Configure the Blog SDK
You need to configure the blog for your site. In the 
Example page we have segregated the blog 
configuration into a separate PHP file for convenience.
<br>See siteBlogConfig.php

Configuration consists of instantiating the BlogEnv class 
and setting several properties.

**_Required: Instantiate the Blog Environment Class:_**

`$blogEnv = new BlogEnv(TBSWLog::LogLevelDebug);`

**_Required: Set Published Blog Documents location:_**
<P> Let TBSW Blog know where your published blog documented reside.

```PHP
$publishedDocsPath = $blogEnv->getBlogPathWebRoot()."BlogDocuments".DIRECTORY_SEPARATOR;
$blogEnv->setPathDocumentsPublished($publishedDocsPath);
```

**_Optional: Set UnPublished Blog Documents location:_**
<P> Let TBSW Blog know where your UNpublished blog documented reside. 
Used by the document manager console.

```PHP
$unPublishedDocsPath = $blogEnv->getBlogPathWebRoot()."BlogDocumentsUnPublished".DIRECTORY_SEPARATOR;
$blogEnv->setPathDocumentsUnPublished($unPublishedDocsPath);
```

**_Required: Set the path to your sites blog viewing page:_**
<P> Let TBSW Blog know where your page used to display the blog is located.

```PHP
$blogEnv->setBlogViewerPage($blogEnv->getBlogPathWebRoot(). "siteBlogViewer.php");
```
**_Optional: Set the path to your sites no blog documents page:_**
<p>This page will be displayed as a blog entry when there are no documents in the blog document folder.
TBSW-Blog will default to the NoBlogPagess.html file found in the TBSW Blog SDK source directory.

```PHP
$blogEnv->setNoBlogPagePath($blogEnv->getBlogPathWebRoot(). "noBlogDocumemnts.html");
```

**_Optional: set the viewing options you would like:_**

```PHP
$blogEnv->setPDFViewerOption(BlogEnv::ViewPDFInNativeBrowser);
$blogEnv->addDocumentTypes(["txt", "pdf", "html", "rtf"]);
```

####PDFViewerOptions:
1.**_ViewPDFInPDFJSViewer_** - Display the PDF document in the Mozilla's PDFjs
viewer that is included with the SDK.
See https://mozilla.github.io/pdf.js/ for details about PDFjs

2.**_ViewPDFInNativeBrowser_** - Display the PDF in the native
browser. On devices that do not 
have a default PDF view the user is often offered only a 
download option.

####Document Types
This options allows you to add a list of document 
file extensions that should be included in the 
Table Of Contents (TOC). All other file types will not 
be shown on the TOC. This allows you to create blog 
documents that may have links to shared content. 
You would not want the shared content to be displayed
on the TOC

###Prepare the current document data
In your viewer page after your BlogEnv configuration code prepare the 
document viewing portion of the SDK. Place this code in your page.

```PHP
$currentKey = $blogEnv->getCurrentBlogItemArgument();
$blogData = new BlogData($blogEnv, $currentKey);
$tocDisplay = $blogData->blogCreateToc();
$currPage = $blogData->getCurrentPage();
$pageTitle = $blogData->getPageTitle($currPage);
$pageDate = $blogData->getPageDateDisplay($currPage);

$prevPage = $blogData->getPage(BlogData::PREV_PAGE);
$PrevPageUrl = $prevPage->getBlogViewerUrl();
$nextPage = $blogData->getPage(BlogData::NEXT_PAGE);
$nextPageUrl = $nextPage->getBlogViewerUrl();
```

##Blog Page Viewer HTML
To view a document the SDK will allow you to fetch 
the current document URL and then use that as the source to a Iframe.
The SDK will handle the TOC navigation for you. When the user 
selects a document from the TOC the SDK will call your viewer 
page with the proper URL of the document.

###Prepare the HTML Head
In the viewer page you need to add the TBSW Blog CSS and Java 
script. The needed HTML code is created for you by the SDK. 
Simply add to the HTML Head block of your blog viewer page 
the following:
```PHP
<?=$blogEnv->getHTMLPageHeadViewer(); ?>
```

###Prepare blog DIVs
The TBSW Blog SDK uses two DIV blocks, One for 
the TOC and one for viewing the current document.
Place blocks where you want the TOC and where you want the viewed document

All Blog Divs should have a TBSW Blog Id. The Blog Css is used to format 
the display of the blog. The ID tags are provided in the SDK BlogEnv class
as constants to reduce typing errors.
You may override the Blog SDK Css with your own.

The sdk will hide/Show the TOC DIV upon a click of the TOC button.

```html
<article id=<?=BlogEnv::BlogHTMLId_Article?>>
    <div id=<?=BlogEnv::BlogHTMLId_Navigation?>>
        <div>
            <button id=<?=BlogEnv::BlogHTMLId_TocButton?> onclick="blogTocToggle()">TOC</button>
        </div>

        <div>
            <?PHP if ($prevPage->isValid()){ ?>
                 <button id=<?=BlogEnv::BlogHTMLId_NavButton?>
                    onclick="window.location.href = '<?=$PrevPageUrl?>';">
                    Older</button>
            <?php } ?>
            <?PHP if ($nextPage->isValid()){ ?>
                <button id=<?=BlogEnv::BlogHTMLId_NavButton?>
                        onclick="window.location.href = '<?=$nextPageUrl?>';">
                    Newer</button>
            <?php } ?>
        </div>
    </div>

    <div id="<?=BlogEnv::BlogHTMLId_TocSection?>">
        <?=$tocDisplay?>
    </div>

    <div id=<?=BlogEnv::BlogHTMLId_DocumentSection?>>
        <div id=<?=BlogEnv::BlogHTMLId_Header?>>
            <div id=<?=BlogEnv::BlogHTMLId_HeaderTitle?>>
                <h5><?= $pageTitle?></h5>
            </div>
            <div id=<?=BlogEnv::BlogHTMLId_HeaderDate?>>
                <i><?=$pageDate?></i>
            </div>
        </div>

        <div id=<?=BlogEnv::BlogHTMLId_blogViewerArea?>>
            <?=$blogData->getBlogViewerDocumentSectionHtml($currPage)?>
        </div>
    </div>
</article>
 ```

#Document Management
The SDK offers the ability to create a administrator 
page that would allow users to create blog content thur a 
Web interface.

The SDK includes a example of a simple Admin page. 
See siteBlogManager.php

The Admin interface uses the elFinder JS package to 
offer a file management console.

See https://github.com/Studio-42/elFinder/wiki for 
more on how to use elFinder.






